@@ -5,6 +5,6 @@ from graia.application.message.chain import MessageChain
 
 class MessageChainCatcher(BaseDispatcher):
     @staticmethod
-    def catch(interface: "DispatcherInterface"):
+    async def catch(interface: "DispatcherInterface"):
         if interface.annotation is MessageChain:
             return interface.event.messageChain
