@@ -26,10 +26,9 @@ class AbstractLogger(ABC):
 
 class LoggingLogger(AbstractLogger):
     def __init__(self, **kwargs) -> None:
-        # logging.basicConfig(format='[%(asctime)s][%(levelname)s]: %(message)s', level=\
-        #    logging.INFO if not kwargs.get("debug") else logging.DEBUG)
         logging.basicConfig(
-            format="[%(asctime)s][%(levelname)s]: %(message)s", level=logging.DEBUG
+            format="[%(asctime)s][%(levelname)s]: %(message)s",
+            level=logging.INFO if not kwargs.get("debug") else logging.DEBUG,
         )
 
     def info(self, msg):
