@@ -319,8 +319,6 @@ class Kanata(BaseDispatcher):
                 raise ExecutionStop()
 
     async def catch(self, interface: DispatcherInterface):
-        if not self.content_token:
-            return
         random_id = random.random()
         current_item = self.parsed_items
         if current_item is not None:
